==> parcel-bundler-1.2.0.tgz: package/.github/ISSUE_TEMPLATE.md <==
<!---
Thanks for filing an issue 😄 ! Before you submit, please read the following:

Search open/closed issues before submitting since someone might have asked the same thing before!
-->

**Choose one:** is this a 🐛 bug report or 🙋 feature request?

<!--- Provide a general summary of the issue in the title above -->

### 🎛 Configuration (.babelrc, package.json, cli command)
<!--- If describing a bug, tell us what your babel configuration looks like -->

```js
{
  "your": { "config": "here" }
}
```

### 🤔 Expected Behavior
<!--- If you're describing a bug, tell us what should happen -->
<!--- If you're suggesting a change/improvement, tell us how it should work -->

### 😯 Current Behavior
<!--- If describing a bug, tell us what happens instead of the expected behavior -->
<!--- If you are seeing an error, please include the full error message and stack trace -->
<!--- If suggesting a change/improvement, explain the difference from current behavior -->

### 💁 Possible Solution
<!--- Not obligatory, but suggest a fix/reason for the bug, -->
<!--- or ideas how to implement the addition or change -->

### 🔦 Context
<!--- How has this issue affected you? What are you trying to accomplish? -->
<!--- Providing context helps us come up with a solution that is most useful in the real world -->

### 🌍 Your Environment
<!--- Include as many relevant details about the environment you experienced the bug in -->

| Software         | Version(s)
| ---------------- | ----------
| Parcel           |  
| Node             | 
| npm/Yarn         | 
| Operating System |

==> parcel-bundler-1.2.1.tgz: package/.github/ISSUE_TEMPLATE.md <==
<!---
Thanks for filing an issue 😄 ! Before you submit, please read the following:

Search open/closed issues before submitting since someone might have asked the same thing before!
-->

**Choose one:** is this a 🐛 bug report or 🙋 feature request?

<!--- Provide a general summary of the issue in the title above -->

### 🎛 Configuration (.babelrc, package.json, cli command)

<!--- If describing a bug, tell us what your babel configuration looks like -->

```js
{
  "your": { "config": "here" }
}
```

### 🤔 Expected Behavior

<!--- If you're describing a bug, tell us what should happen -->

<!--- If you're suggesting a change/improvement, tell us how it should work -->

### 😯 Current Behavior

<!--- If describing a bug, tell us what happens instead of the expected behavior -->

<!--- If you are seeing an error, please include the full error message and stack trace -->

<!--- If suggesting a change/improvement, explain the difference from current behavior -->

### 💁 Possible Solution

<!--- Not obligatory, but suggest a fix/reason for the bug, -->

<!--- or ideas how to implement the addition or change -->

### 🔦 Context

<!--- How has this issue affected you? What are you trying to accomplish? -->

<!--- Providing context helps us come up with a solution that is most useful in the real world -->

### 🌍 Your Environment

<!--- Include as many relevant details about the environment you experienced the bug in -->

| Software         | Version(s) |
| ---------------- | ---------- |
| Parcel           |
| Node             |
| npm/Yarn         |
| Operating System |

<!-- Love parcel? Please consider supporting our collective:
👉  https://opencollective.com/parcel/donate -->
